@@ -1273,7 +1273,11 @@ start:
 	event.start.parent = parent;
 
 	if(manager)
+	{
 		session->setConst("session.manager", manager);
+		if(strchr(manager, '/') || strchr(manager, ':'))
+			session->setConst("session.authorized", manager);
+	}
 	session->setConst("session.caller", caller);
 	session->setConst("session.display", display);
 
