@@ -2335,10 +2335,21 @@ private:
 	friend class __EXPORT BayonneSession;
 	static BayonneBinder *binder;
 
+	class Image : public ScriptImage
+	{
+	public:
+		inline Image() : ScriptImage(NULL, NULL) {};
+		unsigned gatherPrefix(const char *prefix, const char **list, unsigned max);
+	};
+
 protected:
 	virtual const char *submit(const char **data);
 
 	virtual ScriptCompiler *compiler(void);
+	
+	virtual unsigned destinations(Image *img, const char **array, unsigned max);
+
+	virtual bool isDestination(Image *img, const char *name);
 
 	BayonneSession *session(ScriptInterp *interp);
 
@@ -2358,6 +2369,10 @@ public:
 	static const char *submitRequest(const char **data);
 
 	static ScriptCompiler *getCompiler(void);
+
+	static unsigned gatherDestinations(ScriptImage *img, const char **index, unsigned max);
+
+	static bool isDestination(const char *name);
 };
 
 /**
@@ -2592,6 +2607,23 @@ public:
 	 */
 	const char *getExternal(const char *option);
 
+	/**
+	 * Add to an existing symbol.
+	 *
+	 * @param id of symbol.
+	 * @param value to add.
+	 * @return false if not exists.
+	 */
+	bool addSymbol(const char *id, const char *value);
+
+    /**
+     * Clear an existing symbol.
+     *
+     * @param id of symbol.
+     * @return false if not exists.
+     */
+    bool clearSymbol(const char *id);
+
 	/**
 	 * Get event sequence id
 	 *
@@ -2777,6 +2809,15 @@ public:
 	inline const char *defVoicelib(void)
 		{return voicelib;}
 
+	inline const char *getSessionId(void)
+		{return var_sid;};
+
+	inline const char *getSessionParent(void)
+		{return var_pid;};
+
+	inline time_t getSessionStart(void)
+		{return starttime;};
+
 	/**
 	 * Initial kickoff event.
 	 */
