@@ -434,6 +434,30 @@ void BayonneSession::setSid(void)
 	snprintf(var_sid, sizeof(var_sid), "%04d-%08x%02x", timeslot, tstamp, seq++);
 }
 
+bool BayonneSession::addSymbol(const char *id, const char *value)
+{
+	Symbol *sym = mapSymbol(id);
+
+	if(!sym)
+		return false;
+
+	if(!value)
+		return true;
+
+	return append(sym, value);
+}
+
+bool BayonneSession::clearSymbol(const char *id)
+{
+	Symbol *sym = mapSymbol(id);
+
+	if(!sym)
+		return false;
+
+	clear(sym);
+	return true;
+}
+
 const char *BayonneSession::getExternal(const char *id)
 {
 	time_t now;
@@ -1395,7 +1419,7 @@ void BayonneSession::makeIdle(void)
 	BayonneSession *parent, *recall;
 	Symbol *sym;
 	Event event;
-
+		
 	if(ring)
 	{
 		Ring::detach(ring);
