@@ -90,7 +90,7 @@ BayonneDriver(driver, "/bayonne/driver/h323", "h323", false)
 	if(cp)
 		ring_timer = atoi(cp);
 
-	server->setValue("h323.conf", CONFIG_FILES "/h323.conf");	
+	addConfig("h323.conf");	
 }
 
 void Driver::startDriver(void)
