@@ -205,23 +205,8 @@ Assoc()
 	}
 
 	memset(&info, 0, sizeof(info));
-	cp = getLast("encoding");
-	if(!stricmp(cp, "a32"))
-		cp = "adpcm";
-	else if(!stricmp(cp, "a40"))
-		cp = ".a40";
-	else if(!stricmp(cp, "a24"))
-		cp = ".a24";
-	else if(!stricmp(cp, "a16"))
-		cp = ".a16";
-	info.encoding = Bayonne::getEncoding(cp);
-	info.rate = rate8khz;
-	cp = getLast("rate");
-	if(cp)
-		info.rate = atol(cp);
-	info.setFraming(atol(getLast("framing")));
 	registry = false;
-	server->setValue("sip.conf", CONFIG_FILES "/sip.conf");
+	addConfig("sip.conf");
 	Driver::updateConfig(NULL);
 }
 
@@ -230,6 +215,22 @@ void Driver::updateConfig(Keydata *key)
 	timeout_t pickup = updatedMsecTimer("ack");
 	timeout_t hangup = updatedMsecTimer("hangup");
 	const char *dtmf = updatedString("dtmf");
+	const char *cp = updatedString("encoding");
+
+    if(!stricmp(cp, "a32"))
+        cp = "adpcm";
+    else if(!stricmp(cp, "a40"))
+        cp = ".a40";
+    else if(!stricmp(cp, "a24"))
+        cp = ".a24";
+    else if(!stricmp(cp, "a16"))
+        cp = ".a16";
+    info.encoding = Bayonne::getEncoding(cp);
+    info.rate = rate8khz;
+    cp = updatedString("rate");
+    if(cp)
+        info.rate = atol(cp);
+    info.setFraming(updatedMsecTimer("framing"));
 
 	audio_timer = updatedMsecTimer("audio");
 	accept_timer = updatedMsecTimer("accept");
@@ -503,6 +504,51 @@ bool Driver::isAvailable(const char *ext)
 	return rtn;
 }
 
+Registry *Driver::getAnonymous(ScriptImage *img, const char *hid, const char *dialed)
+{
+	Registry *reg;
+	char buf[128];
+
+	if(dialed && *dialed)
+	{
+		snprintf(buf, sizeof(buf), "uri.%s", dialed);
+		reg = (Registry *)img->getPointer(buf);
+		if(reg)
+			return reg;
+	}
+
+	if(!hid || !*hid)
+		return NULL;
+
+	snprintf(buf, sizeof(buf), "sipanon.%s", hid);
+	reg = (Registry *)img->getPointer(buf);
+	if(!reg)
+		reg = (Registry *)img->getPointer("sipanon.*");
+	return reg;
+}
+
+bool Driver::isLocalName(const char *hid)
+{
+	char names[128];
+	char *tok, *np;
+
+	if(!getString("localnames", names, sizeof(names)))
+		return true;
+
+	if(!hid)
+		return true;
+
+	np = strtok_r(names, " ,;:\t\r\n", &tok);
+	while(np)
+	{
+		if(!stricmp(np, hid))
+			return true;
+
+		np = strtok_r(NULL, " ,;:\t\r\n", &tok);
+	}
+	return false;
+}
+
 unsigned Driver::getRegistration(regauth_t *data, unsigned count, const char *id)
 {
 	unsigned idx = 0;
@@ -1077,9 +1123,9 @@ bool Driver::getRegistry(eXosip_event_t *sevent, Registry **reg, ScriptImage *im
 	osip_proxy_authorization_t *auth;
 	char buf[256];
 
-	*reg = NULL;	
+	*reg = NULL; 
 
-        if(osip_message_get_proxy_authorization(sevent->request, 0, &auth) != 0)
+	if(osip_message_get_proxy_authorization(sevent->request, 0, &auth) != 0)
 		return true;
 
 	if(!auth)
@@ -1742,11 +1788,15 @@ const char *Driver::registerScript(ScriptImage *img, Line *line)
 		{
 			snprintf(buf, sizeof(buf), "sipanon.%s", reg->address);
 			img->setPointer(buf, reg);
+			if(!img->getPointer("sipanon.*"))
+				img->setPointer("sipanon.*", reg);
 		}
 		else
 			img->setPointer("sipanon.*", reg);
 		goto add;
 	}
+	else if(!strnicmp(reg->type, "pub", 3))
+		reg->type = "anon";
 
 	if(ext)
 		reg->type = "extern";
@@ -2811,9 +2861,27 @@ answer:
 				goto sip404;
 
 			reg = NULL;
-			if(!getRegistry(sevent, &reg, img))
-				goto sip401;
+			if(from->url)
+				cp = from->url->host;
+			else
+				cp = NULL;
 
+			if(!isLocalName(cp))
+			{
+				if(to->url)
+					cp = to->url->host;
+				else
+					cp = NULL;
+				reg = getAnonymous(img, cp, dialed);
+				if(!reg)
+					goto sip403;
+			}
+			else
+			{
+				reg = getAnonymous(img, NULL, dialed);
+				if(!reg && !getRegistry(sevent, &reg, img))
+					goto sip401;
+			}
 			reg_inband = dtmf_inband;
 			reg_payload = dtmf_negotiate;
 
@@ -2840,6 +2908,11 @@ answer:
 					auth = "peer";
 					goto validate;
 				}
+				if(!stricmp(reg->type, "anon"))
+				{
+					auth = "anon";
+					goto validate;
+				}
 				goto sip404;
 			}
 
@@ -2871,9 +2944,6 @@ answer:
 
 			if(!reg && !peer)
 			{
-				reg = (Registry *)img->getPointer("sipanon.*");
-				if(reg)
-					goto validate;
 				snprintf(buf, sizeof(buf), "sipanon.%s", to->url->host);
 				reg = (Registry *)img->getPointer(buf);
 				if(reg)
@@ -2902,6 +2972,7 @@ validate:
 					goto sip480;
 
 				scr = img->getScript(reg->scr->name);
+
 				cp = reg->dtmf;
 				if(cp && *cp)
 				{
@@ -2925,6 +2996,12 @@ sip404:
 				eXosip_call_send_answer(sevent->tid, 404, NULL);
 				eXosip_unlock();				
 				goto clear;
+sip403:
+                endImage(img);
+                eXosip_lock();
+                eXosip_call_send_answer(sevent->tid, 403, NULL);
+                eXosip_unlock();
+                goto clear;
 sip401:
 				endImage(img);
 				eXosip_lock();
@@ -3000,7 +3077,9 @@ sip480:
 			{
 				++reg->traffic->call_attempts.iCount;
 				++reg->traffic->call_complete.iCount;
-				if(!stricmp(reg->type, "anon") || !strnicmp(reg->type, "ext", 3) || !stricmp(reg->type, "gw"))
+				if(!stricmp(reg->type, "anon") || 
+				   !strnicmp(reg->type, "ext", 3) || 
+				   !stricmp(reg->type, "gw")) 
 					snprintf(cbuf, sizeof(cbuf), "uri.%s", reg->localid);
 				else
 					snprintf(cbuf, sizeof(cbuf), "sipreg.%d", reg->regid);
@@ -3018,6 +3097,11 @@ sip480:
 					session->setConst("session.identity", buf);
 					session->setConst("session.group", reg->group);
 				}
+				else if(!strnicmp(reg->type, "anon", 4))
+				{
+					snprintf(buf, sizeof(buf), "sip:%s", reg->localid);
+					session->setConst("session.anonymous", buf);
+				}
 				else
 					session->setConst("session.service", reg->service);
 			
@@ -3207,6 +3291,20 @@ sip415:
 				
 			addString(sdp, 4096, cbuf);
 
+			if(to->url && to->url->host)
+			{
+				cp = strchr(to->url->host, '.');
+				if(cp)
+					session->setConst("session.hostname", to->url->host);
+				else
+				{
+					snprintf(buf, sizeof(buf), "%s.localdomain", to->url->host);
+					session->setConst("session.hostname", buf);
+				}
+			}
+			if(from->url && from->url->host)
+				session->setConst("session.peername", from->url->host);
+
 			if(session->dtmf_sipinfo)
 				session->setConst("session.dtmfmode", "info");
 			else if(session->dtmf_payload)
