@@ -932,7 +932,9 @@ dialing:
 
 			if(!strnicmp(reg->type, "ext", 3))
 			{
-				setConst("session.identity", reg->localid);
+				snprintf(buf, sizeof(buf), "sip:%s", reg->localid);
+				setConst("session.authorized", buf);
+				setConst("session.identity", buf);
 				setConst("session.group", reg->group);
 			}
 			else if(reg->service)
@@ -940,7 +942,6 @@ dialing:
 
 			snprintf(nbuf, sizeof(nbuf), "%d", instance);
 			setConst("session.instance", nbuf);
-			BayonneService::notify(this);
 		}
 		else
 		{
@@ -954,7 +955,6 @@ dialing:
 		}
                 snprintf(nbuf, sizeof(nbuf), "%d", instance);
                 setConst("session.instance", nbuf);
-                BayonneService::notify(this);
 					
 		to = getSymbol("session.uri_remote");
 		from = getSymbol("session.uri_caller");
