@@ -22,7 +22,7 @@ namespace moduleTCP {
 using namespace ost;
 using namespace std;
 
-class Service : public BayonneService, public BayonneZeroconf, public Keydata
+class Service : public BayonneService, public BayonneZeroconf, public StaticKeydata
 {
 private:
 	void run(void);
