@@ -24,38 +24,20 @@ using namespace std;
 Service Service::tcp;
 bool Service::active = false;
 
+static Keydata::Define defkeys[] = {
+    {"interface", "127.0.0.1"},
+    {"port", "5555"},
+    {"secret", "pass"},
+    {"zeroconf", "yes"},
+    {NULL, NULL}};
+
 Service::Service() :
 BayonneService(0, 0), 
 BayonneZeroconf("_tcpmon._tcp", ZEROCONF_IPV4),
-Keydata("/bayonne/module/tcpmon")
+StaticKeydata("/bayonne/module/tcpmon", defkeys)
 {
-	static Keydata::Define defkeys[] = {
-	{"interface", "127.0.0.1"},
-	{"port", "5555"},
-	{"secret", "pass"},
-	{"zeroconf", "yes"},
-	{NULL, NULL}};
-
-	const char *cp;
-
-	if(Bayonne::getUserdata())
-	        load("~bayonne/tcpmon");
-
-	load(defkeys);
-#ifdef	WIN32
-	loadFile("C:\\Program Files\\GNU Telephony\\Bayonne Config\\module.ini", "tcpmon");
-#endif
-
-	cp = getLast("zeroconf");
-	switch(*cp)
-	{
-	case 'y':
-	case 'Y':
-	case 't':
-	case 'T':
-	case '1':
-		zeroconf_port = atoi(getLast("port"));	
-	}
+	if(getBoolean("zeroconf"))
+		zeroconf_port = getValue("port");	
 }
 
 void Service::stopService(void)
@@ -66,8 +48,8 @@ void Service::stopService(void)
 
 void Service::run(void)
 {
-	InetAddress addr(getLast("interface"));
-	tpport_t port = atoi(getLast("port"));
+	InetAddress addr(getString("interface"));
+	tpport_t port = getValue("port");
 	TCPSocket tcp(addr, port);
 	Session *session;
 
