@@ -58,11 +58,13 @@ void Session::help(void)
 	*tcp() << "drivers [names..] - display loaded drivers" << endl;
 	*tcp() << "global id cmd [val] - manipulate global" << endl;
 	*tcp() << "hold sid - hold a running session" << endl;
+	*tcp() << "jhold sid - hold a joined session" << endl;
 	*tcp() << "mon state|all timeslots.. - enable state monitoring" << endl;
 	*tcp() << "nomon timeslots.. - disable state monitoring" << endl;
-        *tcp() << "reg - display protocol registrations" << endl;
+    *tcp() << "reg - display protocol registrations" << endl;
 	*tcp() << "refer sid target - refer bridge leg" << endl;
 	*tcp() << "reload - reload script configuration" << endl;
+	*tcp() << "release sid - release refer state" << endl;
 	*tcp() << "resume sid - resume from hold state" << endl;
 	*tcp() << "shutdown - shutdown server" << endl;
 	*tcp() << "spans - list active spans in server" << endl;
@@ -671,6 +673,50 @@ void Session::run(void)
 				else
 					*tcp() << "*** hold ignored" << endl;
 			}
+			else if(!stricmp(*argv, "release"))
+			{
+				if(!argv[1])
+				{
+					*tcp() << "*** missing session id" << endl;
+					goto skip;
+				}
+				session = getSid(argv[1]);
+				if(!session)
+				{
+					*tcp() << "*** invalid or unknown call session" << endl;
+					goto skip;
+				}
+				memset(&event, 0, sizeof(event));
+				event.id = DROP_RECALL;
+				if(session->postEvent(&event))
+					*tcp() << "script released" << endl;
+				else
+					*tcp() << "*** release ignored" << endl;
+			}
+			else if(!stricmp(*argv, "jhold"))
+			{
+				if(!argv[1])
+				{
+					*tcp() << "*** missing session id" << endl;
+					goto skip;
+				}
+				session = getSid(argv[1]);
+				if(!session)
+				{
+					*tcp() << "*** invalid or unknown call session" << endl;
+					goto skip;
+				}
+				memset(&event, 0, sizeof(event));
+				event.id = CALL_HOLD;
+				session->enter();
+				if(!session->isJoined())
+					*tcp() << "*** session not joined" << endl;
+				else if(session->postEvent(&event))
+					*tcp() << "script held" << endl;
+				else
+					*tcp() << "*** hold ignored" << endl;
+				session->leave();
+			}
 			else if(!stricmp(*argv, "resume"))
 			{
 				if(!argv[1])
