@@ -25,6 +25,8 @@ using namespace std;
 typedef	Bayonne::rpcint_t rpcint_t;
 typedef	rpcint_t rpcbool_t;
 
+extern bool xmlrpc_update;
+
 class Server : public Bayonne
 {
 public:
@@ -50,6 +52,36 @@ public:
 		{sla[0] = 0;};
 };	
 
+static void server_version(BayonneRPC *rpc)
+{
+    if(rpc->getCount())
+    {
+        rpc->sendFault(3, "Invalid Parameters");
+        return;
+    }
+	rpc->buildResponse("(ii)", 
+		"current", (rpcint_t)1,
+		"prior", (rpcint_t)0);
+}
+
+static void server_update(BayonneRPC *rpc)
+{
+    if(rpc->getCount())
+    {
+        rpc->sendFault(3, "Invalid Parameters");
+        return;
+    }
+
+    if(!rpc->transport.authorized)
+    {
+        rpc->transportFault(401, "Not Authorized");
+        return;
+	}
+
+	xmlrpc_update = true;
+	rpc->sendSuccess();
+}
+	
 static void server_reload(BayonneRPC *rpc)
 {
 	if(rpc->getCount())
@@ -90,6 +122,64 @@ static void server_callstats(BayonneRPC *rpc)
 				(rpcint_t)Server::total_active_calls
 		);
 }
+
+static void server_listDestinations(BayonneRPC *rpc)
+{
+	const char *list[1024];
+	ScriptImage *img = Bayonne::useImage();
+	unsigned count = 0, pos = 0;
+
+	if(rpc->getCount() != 1)
+    {
+        rpc->sendFault(3, "Invalid Parameters");
+        return;
+    }
+
+	rpc->buildResponse("[");
+	if(img)
+		count = BayonneBinder::gatherDestinations(img, list, 1024);
+	while(pos < count)
+		rpc->buildResponse("!s", list[pos++]);
+	rpc->buildResponse("]");
+	if(img)
+		Bayonne::endImage(img);
+}
+
+static void server_isDestination(BayonneRPC *rpc)
+{
+	const char *dest;
+
+	if(rpc->getCount() != 1)
+	{
+		rpc->sendFault(3, "Invalid Parameters");
+		return;
+	}
+
+	dest = rpc->getIndexed(1);
+	if(!dest || !*dest)
+	{
+		rpc->sendFault(4, "Invalid Parameter Value");
+		return;
+	}
+
+	rpc->buildResponse("b", (rpcbool_t)BayonneBinder::isDestination(dest));
+}
+
+static void server_getPaths(BayonneRPC *rpc)
+{
+    if(rpc->getCount())
+        rpc->sendFault(3, "Invalid Parameters");
+    else
+        rpc->buildResponse("(ss)",
+            "prefix", Server::getLast("prefix"),
+            "config", Server::getLast("config"),
+			"prompts", Server::getLast("prompts"),
+			"logfiles", Server::getLast("logfiles"),
+			"runfiles", Server::getLast("runfiles"),
+			"tmp", Server::getLast("tmp"),
+			"tmpfs", Server::getLast("tmpfs")
+        );
+}
 	
 static void server_status(BayonneRPC *rpc)
 {
@@ -298,6 +388,10 @@ static void server_getInfo(BayonneRPC *rpc)
 }
 
 static Bayonne::RPCDefine dispatch[] = {
+	{"version", server_version,
+		"API version number of server rpc", "struct"},
+	{"getPaths", server_getPaths,
+		"Return server directory layout", "struct"},
 	{"status", server_status,
 		"Return bayonne runtime status information", "struct"},
 	{"callstats", server_callstats,
@@ -306,6 +400,8 @@ static Bayonne::RPCDefine dispatch[] = {
 		"Return static server information", "struct"},
 	{"reload", server_reload,
 		"Reload server configuration while running", "nil"},
+	{"update", server_update,
+		"Notify update reload request", "nil"},
 	{"setLevel", server_setService,
 		"Set service level for the server", "nil, string"},
 	{"clearLevel", server_setRunning,
@@ -318,6 +414,10 @@ static Bayonne::RPCDefine dispatch[] = {
 		"Clear global symbol", "boolean, string"},
 	{"createSymbol", server_createSymbol,
 		"Create global symbol of specified size", "boolean, string, int"},
+	{"isDestination", server_isDestination,
+		"Check if a given destination is configured", "boolean, string"},
+	{"listDestinations", server_listDestinations,
+		"List configured destinations for this server"},
 	{NULL, NULL, NULL, NULL}};
 
 static Bayonne::RPCNode xmlrpc_server("server", dispatch);
