@@ -25,6 +25,16 @@ using namespace std;
 typedef	Bayonne::rpcint_t rpcint_t;
 typedef	rpcint_t rpcbool_t;
 
+static void span_version(BayonneRPC *rpc)
+{
+    if(rpc->getCount() != 1)
+    {
+        rpc->sendFault(3, "Invalid Parameters");
+        return;
+    }
+	rpc->buildResponse("i", (rpcint_t)1);
+}
+
 static void span_getInfo(BayonneRPC *rpc)
 {
 	BayonneSpan *span = NULL;
@@ -181,6 +191,8 @@ static void span_callstats(BayonneRPC *rpc)
 }
 
 static Bayonne::RPCDefine dispatch[] = {
+	{"version", span_version,
+		"API version number of span rpc", "struct"},
 	{"suspend", span_suspend,
 		"Suspend span", "boolean, int"},
 	{"resume", span_resume,
