@@ -20,6 +20,17 @@ namespace server {
 using namespace ost;
 using namespace std;
 
+bool Methods::scrExit(void)
+{
+	const char *reason = getValue(NULL);
+	ScriptMethods *methods = (ScriptMethods *)this;
+
+	if(reason)
+		setConst("session.exit_reason", reason);
+
+	return methods->scrExit();
+}
+
 bool Methods::scrTrap(void)
 {
 	const char *id = getKeyword("id");
