@@ -519,6 +519,8 @@ int main(int argc, char **argv)
                                 keyserver.getLast("user"));
                         stop(-1);
                 }
+				Process::setEnv("USER", keyserver.getLast("user"), true);
+				Process::setEnv("HOME", keypaths.getLast("datafiles"), true);
         }
 	else
 		Process::setGroup(keyserver.getLast("group"));
