@@ -267,6 +267,7 @@ public:
 	bool scrDTMF(void);
 	bool scrMF(void);
 	bool scrTransfer(void);
+	bool scrExit(void);
 };
 
 class Checks : public ScriptChecks, public Bayonne
@@ -304,6 +305,7 @@ public:
 	const char *chkTransfer(Line *line, ScriptImage *img);
 	const char *chkChildSignal(Line *line, ScriptImage *img);
 	const char *chkDialer(Line *line, ScriptImage *img);
+	const char *chkExit(Line *line, ScriptImage *img);
 };
 
 extern Runtime runtime;
